==> haskell-singleton-bool-0.1.7-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singleton-bool
version:              0.1.7
visibility:           public
id:                   singleton-bool-0.1.7-2tDFkbjFLK6CMTjgJvZrRz
key:                  singleton-bool-0.1.7-2tDFkbjFLK6CMTjgJvZrRz
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Web
abi:                  de3a3cdb9885aa7f037e3cd7f8e7816d
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.2.8/site-local/singleton-bool-0.1.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/singleton-bool-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.7-2tDFkbjFLK6CMTjgJvZrRz
depends:
    base-4.16.4.0 boring-0.2.1-Icfsg6aSH6SpFFKOquZU
    dec-0.0.5-AiPCixVZqIRKIMMKnR0Fi3 deepseq-1.4.6.1
    some-1.0.5-L5glA67mR8RJufLDsA2lRz

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singleton-bool-0.1.7-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singleton-bool
version:              0.1.7
visibility:           public
id:                   singleton-bool-0.1.7-1uubXFtCW7Z2sKJGUSh2pN
key:                  singleton-bool-0.1.7-1uubXFtCW7Z2sKJGUSh2pN
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Web
abi:                  c0672652f9f5cea835b22eb582e0c14a
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.2.8/site-local/singleton-bool-0.1.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/singleton-bool-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.7-1uubXFtCW7Z2sKJGUSh2pN
depends:
    base-4.16.4.0 boring-0.2.1-4ay7NZ1mR0V485tuSNtr0u
    dec-0.0.5-mxthkKDKJzCevwszd0Rua deepseq-1.4.6.1
    some-1.0.5-L5glA67mR8RJufLDsA2lRz

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
